<?php

/**
 * @file
 * The forms used by plugin manager ajax search.
 */

/**
 * Plugin Manager AJAX Search page.
 */

/**
 * This is the main function for the Ajax Search page of Plugin Manager.
 */
function plugin_manager_ajax_search() {
  drupal_add_js(drupal_get_path('module', 'plugin_manager_ajax_search') . '/js/plugin_manager_ajax_search.js');
  drupal_add_css(drupal_get_path('module', 'plugin_manager_ajax_search') . '/css/plugin_manager_ajax_search.css');

  // If the repository is over 24 hours old then update it.
  if (variable_get("plugin_manager_last_reload", 0) + 604800 < date('U')) {
    drupal_set_message(l(t('The repository might be out of date.  Update it by clicking here.'), 'admin/config/system/plugin_manager/reload'));
  }
  $headers = array(t('Queue'), t('Name'), t('Tags'), t('Project Page'));
  $letters = array(
    'A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M',
    'N', 'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X', 'Y', 'Z',
  );

  $html = t("This is a prototype of an interactive search for the Plugin Manager module.  Try typing in 'module' or 'image'.") . "<br/>";
  $html .= "<fieldset><legend>" . t('Search') . "</legend><input id='sinput'/> <button id='search'>" . t('Search') . "</button>";
  $html .= t('Filter') . ": <a id='showall' class='selected' href='javascript:void(0)'>" . t('All') . "</a> <a id='showmodules' href='javascript:void(0)'>" . t('Modules') . "</a> <a id='showthemes' href='javascript:void(0)'>" . t('Themes') . "</a>";
  $html .= "</fieldset>";
  $html .= "<fieldset><legend>" . t('Browse') . "</legend>" . t('By Category') . ": <select onchange='pmsearch.showtag(this.value)'><option> -- " . t('Categories') . " -- </option>";

  $result = db_query("SELECT tag FROM {plugin_manager_taxonomy} WHERE tag NOT IN('Modules') GROUP BY tag ORDER BY tag");

  foreach ($result as $record) {
    $html .= '<option value="' . $record->tag . '">' . t($record->tag) . '</option>';
  }
  $html .= '</select><br/>';
  $html .= t('Alphabetical') . ': ';
  for ($i = 0; $i < 26; $i++) {
    $html .= '<a class="showletter" href="javascript:pmsearch.showletter(\'' . $letters[$i] . '\')">' . t($letters[$i]) . '</a> ';
  }
  $html .= '</fieldset>';

  $html .= "<fieldset><legend><a id='queuelink' href='javascript:void(0)'>" . t('Loading') . "...</a></legend>";
  $table_vars = array(
    'header' => array(
      'data' => $headers,
    ),
    'rows' => array(
    ),
    'attributes' => array(
      'id' => array('queue'),
    ),
  );
  $html .= theme('table', $table_vars);
  $html .= "</fieldset>";

  $form = drupal_get_form('plugin_manager_ajax_search_form');
  $html .= drupal_render($form);

  unset($table_vars['attributes']);
  $table_vars['attributes']['class'] = array('pmsearch');
  $html .= theme('table', $table_vars);

  return $html;
}

/**
 * Plugin Manager AJAX Search form.
 */
function plugin_manager_ajax_search_form() {
  $form = array();
  $queue = variable_get('plugin_manager_queue', array());
  foreach ($queue as $name => $value) {
    $form[$name] = array('#type' => 'hidden', '#value' => 'true');
  }
  $form['submit'] = array('#type' => 'submit', '#value' => t('Install'));
  return $form;
}

/**
 * Plugin Manager AJAX Search form submit handler.
 */
function plugin_manager_ajax_search_form_submit($form, &$form_state) {
  $queue = array();
  foreach ($form['#post'] as $name => $value) {
    if ($value == 'true') {
      $queue[$name] = $name;
    }
  }
  drupal_goto('admin/config/system/plugin_manager/install');
}

/**
 * Plugin Manager AJAX Search callback.
 */
function plugin_manager_ajax_search_callback() {

  $result = db_query('SELECT title, short_name FROM {plugin_manager_repository} ORDER BY title');

  $files = module_rebuild_cache();

  foreach ($result as $record) {
    if (isset($files[$record->short_name])) {
      continue;
    }

    $tags_result = db_query('SELECT pmt.tag AS tag FROM {plugin_manager_taxonomy} pmt WHERE pmt.short_name = :short_name ORDER BY tag', array(':short_name' => $record->short_name));

    $tags = array();
    foreach ($tags_result as $tag_record) {
      $tags[] = $tag_record->tag;
    }
    echo $record->short_name . ':' . $record->title . ':' . implode(' | ', $tags) . "\n";
  }
  exit(0);
}
